Learn R Programming

magicaxis (version 2.0.1)

magicaxis-package:

Description

Functions to make pretty axes (major and minor) on scientific plots. Particularly effort is made on producing nice log plot outputs. The core function produces pretty axis labelling in a number of circumstances that are often used in scientific plotting. There is a higher level interface to a generic plot function that will usually produce nice plots, even without much though on the users part.

Arguments

Details

Package: magicaxis
Type: Package
Version: 2.0.1
Date: 2017-05-11
License: GPL-3
Depends: MASS, plotrix, sm, mapproj, celestial