magtri(chains, samples, samptype = "end", grid = FALSE, tick = FALSE)chains.
chains ('end', the default since samples are usually better towards the end of a set of psoterior chain samples) or randomly selected ('ran', should only be used if you are confident the posterior chains supplied are true stationary samples).
magaxis for details.
Other types of data can be plotted using this function of course, but the default setup is tuned towards being useful for MCMC posterior chain samples.
The contour levels shown are the defaults for magcon, i.e. they contain 50% (lty=2), 68% (lty=1) and 95% (lty=3) of the posterior chains.
The red cross shows the mean for the sampled posterior chain. The red vertical dashed line traces this over the contour plots. The red dotted line shows the +/- SD range of the sampled posterior chain.
magconSigma=matrix(c(10,3,-5,3,12,8,-5,8,20),3,3)
chains=mvrnorm(n=1000, mu=1:3, Sigma=Sigma)
magtri(chains,tick=TRUE)
Run the code above in your browser using DataLab